<script setup>
import { ref, nextTick } from 'vue';
import { get, post, postBlob, postForm } from '@/utils/request.js'
import { formatMessage } from '@/utils/localeUtils.js';
import { message } from 'ant-design-vue';

const submitButton = ref(null);
const isSave = ref(true);
const open = ref(false);
const initFormData = {}
let formData = ref(initFormData);
const treeData = ref(null);

const emit = defineEmits(['tableReload'])

const handleOk = (e) => {
    nextTick(() => {
        setTimeout(() => {
            submitButton.value.$el.click();
        }, 100);
    });
};

const onFinish = values => {
    // console.log('Success:', values);
    open.value = false;
    post(isSave.value ? '/api/userLogin/save' : '/api/userLogin/update', formData.value).then((resp) => {
        let result = resp.data;
        if (result.code === 200) {
            message.success(formatMessage('page.update.success', '更新成功'));
        } else {
            message.error(result.msg);
        }
        emit('tableReload', 'reload')
    })
};
const onFinishFailed = errorInfo => {
    console.log('Failed:', errorInfo);
};

const UserQueryList = ref(null);
UserQuery();
function UserQuery() {
    postForm('/api/user/query', {}).then(resp => {
        let result = resp.data;
        UserQueryList.value = result.data;
    })
}


defineExpose({
    open,
    formData,
    initFormData,
    treeData,
    isSave,
})

</script>

<script>
export default {
    name: '登录日志-edit'
}
</script>

<template>
    <div>
        <a-modal v-model:open="open"
            :title="isSave ? formatMessage('page.add', '添加') : formatMessage('page.edit', '编辑')" @ok="handleOk"
            style="width: 600px;">
            <a-form :model="formData" name="formTable" :label-col="{ span: 8 }" :wrapper-col="{ span: 16 }"
                style="display: flex;justify-content: space-between;flex-wrap: wrap;" autocomplete="off"
                @finish="onFinish" @finishFailed="onFinishFailed">
                <a-form-item label="用户" name="userId" style="width: 250px;" :rules="[{ required: true }]">
                    <a-select v-model:value="formData.userId" placeholder="Select users" style="width: 100%" show-search
                        :options="UserQueryList" optionFilterProp="label" optionLabelProp="label">
                    </a-select>
                </a-form-item>
                <a-form-item label="密钥" name="token" style="width: 250px;">
                    <a-input v-model:value="formData.token" />
                </a-form-item>
                <a-form-item label="登录ip" name="ip" style="width: 250px;">
                    <a-input v-model:value="formData.ip" />
                </a-form-item>
                <a-form-item label="类型" name="type" style="width: 250px;">
                    <a-select v-model:value="formData.type" :options="[
                        { label: '登录成功', value: 0 },
                        { label: '登录失败', value: 1 },
                        { label: '退出登录', value: 2 },
                        { label: '续签token', value: 3 },
                    ]">
                    </a-select>
                </a-form-item>
                <a-form-item label="添加时间" name="createTime" style="width: 250px;">
                    <a-date-picker v-model:value="formData.createTime" show-time format="YYYY-MM-DD HH:mm:ss"
                        value-format="YYYY-MM-DD HH:mm:ss" />
                </a-form-item>
                <a-form-item label="登录系统" name="system" style="width: 250px;">
                    <a-input v-model:value="formData.system" />
                </a-form-item>
                <a-form-item label="备注" name="memo" style="width: 250px;">
                    <a-input v-model:value="formData.memo" />
                </a-form-item>

                <a-form-item>
                    <a-button type="primary" html-type="submit" ref="submitButton"
                        style="visibility: hidden;">Submit</a-button>
                </a-form-item>
            </a-form>
        </a-modal>
    </div>
</template>

<style></style>
